@@ -30,7 +30,12 @@ ucp_sort <- function(x, decreasing = FALSE) {
 }
 
 #' @rdname unicode_utilities
+#' @param pua_combining Additional Unicode code points to be considered
+#'                      as a \dQuote{combining} character such as characters
+#'                      defined in the Private Use Area (PUA) of a font.
 #' @export
-is_combining_character <- function(x) {
-    Unicode::u_char_property(x, "Canonical_Combining_Class") > 0L
+is_combining_character <- function(x, pua_combining = character(0)) {
+    (Unicode::u_char_property(x, "Canonical_Combining_Class") > 0L) |
+    (Unicode::u_char_property(x, "General_Category") == "Me") |
+    (x %in% pua_combining)
 }
